import java.awt.*;
import java.applet.*;
import java.io.*;
import java.util.*;

public class TestAppletNamed2 extends Applet
{
  public void init () throws java.io.IOException
  {
    System.out.println ("TestAppletNamed2.init");

    AppletContext ac = getAppletContext ();

    if (ac == null)
      {
	System.err.println ("error: applet context in applet 2 is null");
	return;
      }

    ac.setStream ("applet 2 stream 1", new PipedInputStream ());
    ac.setStream ("applet 2 stream 2", new PipedInputStream ());
    ac.setStream ("applet 2 stream 3", new PipedInputStream ());
    ac.setStream ("applet 2 stream 4", new PipedInputStream ());
    ac.setStream ("applet 2 stream 5", new PipedInputStream ());
    ac.setStream ("applet 2 stream 6", new PipedInputStream ());
    ac.setStream ("applet 2 stream 7", new PipedInputStream ());

//     KeyboardFocusManager m = new DefaultKeyboardFocusManager ();

//     System.out.println ("applet 2 setting keyboard manager: " + m);

//     KeyboardFocusManager.setCurrentKeyboardFocusManager (m);
  }

  public void start ()
  {
    System.out.println ("TestAppletNamed2.start");

    System.out.println ("applet 2 current keyboard manager: " + KeyboardFocusManager.getCurrentKeyboardFocusManager ());
  }
}
